@@ -218,7 +218,7 @@ def alerts(context):  # pylint: disable=unused-argument
 
 @alerts.command(name='query',
                 help='Example: "status: closed AND teams: <opsgenie-team> AND description: *<some-hostname>*"')
-@click.option('--query', required=True)
+@click.option('--query', type=click.STRING, required=True)
 @click.option('--sort-by', "--sort_by")
 @click.pass_context
 def alerts_query(context, query, sort_by):
@@ -233,6 +233,7 @@ def alerts_query(context, query, sort_by):
         A table output of the alerts on success and a string otherwise
 
     """
+    query = query.replace("\\'", "'").replace('\\"', '"')
     result = context.obj['opsgenie'].query_alerts(query)
     table_fields = ['message', 'tags', 'integration', 'createdAt']
     if sort_by:
